import org.gicentre.processing.utils.zoom.*;

// Simple sketch to demonstrate the ZoomPan class for interactively zooming and
// panning a sketch's display.
// Version 1.2, 18th July, 2009.
// Author Jo Wood.

// ------------------ Object variables --------------------

ZoomPan zoomer;    // This should be declared outside any methods.
PFont font;        // For text display.
PVector mousePos;  // Stores the mouse position.

// ------------------- Initialisation ---------------------

void setup()
{
  size(600,300);
  smooth();
   
  font = createFont("Arial",12);  // Set up font for text display.
  textFont(font,12);
  
  zoomer = new ZoomPan(this);  // Initialise the zoomer.
  zoomer.setMouseMask(SHIFT);  // Only zoom if the shift key is down.
                            
                               // Monitor end of zoom/pan events.
  zoomer.addZoomPanListener(new MyListener());
}

// ------------------ Processing draw --------------------

void draw()
{
  background(221,221,204); 
  
  pushMatrix();    // Store a copy of the unzoomed screen transformation.
  
  zoomer.transform(); // Enable the zooming/panning.
  
  // Do some drawing that can be zoomed and panned.  
  fill(170,128,128);
  stroke(50);
  ellipse(width/2,height/2,50,50);
  noStroke();
  
  //  Get the mouse position taking into account any zooming and panning.
  mousePos = zoomer.getMouseCoord();
  
  // Do some drawing that will not be zoomed or panned.
  popMatrix();    // Restore the unzoomed screen transformation.
  fill(255,255,255,200);
  rect(0,height-21,width-1,20);
  fill(80);
  text("Hold shift down and drag mouse to zoom and pan. Press 'R' to reset view. "+
       "Mouse at "+ mousePos.x+","+mousePos.y,10,height-6);
}

// ------------------ Processing keyboard handling --------------------

/** Reset the zoomer to its untransformed view if the 'R' key is pressed.
 */
void keyPressed()
{
  if (key=='r')
  {
    zoomer.reset();
  }
}

/** Simple class to show how the end of a zoom or pan event can be monitored.
 */
class MyListener implements ZoomPanListener
{
  void panEnded()
  {
    println("Panning stopped");
  }
  
  void zoomEnded()
  {
    println("Zooming stopped");
  }
}
